@@ -72,6 +72,11 @@ WaylandIntegration *WaylandIntegration::self()
     return &privateWaylandIntegrationSelf()->self;
 }
 
+KWayland::Client::Registry *WaylandIntegration::registry() const
+{
+    return m_registry;
+}
+
 KWayland::Client::ConnectionThread *WaylandIntegration::waylandConnection() const
 {
     return m_waylandConnection;
